# import pyspacemouse
# import time
#
# success = pyspacemouse.open()
# if success:
#     while 1:
#         state = pyspacemouse.read()
#         print(state.x, state.y, state.z)
#         time.sleep(0.01)


# import pyspacemouse
# import time
#
#
# def button_0(state, buttons, pressed_buttons):
#     print("Button:", pressed_buttons)
#
#
# def button_0_1(state, buttons, pressed_buttons):
#     print("Buttons:", pressed_buttons)
#
#
# def someButton(state, buttons):
#     print("Some button")
#
#
# def callback():
#     button_arr = [
#         pyspacemouse.ButtonCallback(0, button_0),
#         pyspacemouse.ButtonCallback([1], lambda state, buttons, pressed_buttons: print("Button: 1")),
#         pyspacemouse.ButtonCallback([0, 1], button_0_1),
#     ]
#
#     success = pyspacemouse.open(dof_callback=pyspacemouse.print_state, button_callback=someButton,
#                                 button_callback_arr=button_arr)
#     if success:
#         while True:
#             pyspacemouse.read()
#             time.sleep(0.01)
#
#
# if __name__ == '__main__':
#     callback()


import pyspacemouse
import time

success = pyspacemouse.open(dof_callback=pyspacemouse.print_state, button_callback=pyspacemouse.print_buttons)
if success:
    while 1:
        state = pyspacemouse.read()
        time.sleep(0.01)

# import pyspacemouse
# import time
#
# cfg = pyspacemouse.Config(
#     dof_callback_arr=[
#         pyspacemouse.DofCallback("x", lambda state, buttons: print("Button: 0")),
#         pyspacemouse.DofCallback("y", lambda state, buttons: print("Button: 1")),
#     ],
#     button_callback_arr=[
#         pyspacemouse.ButtonCallback(1, lambda axis: print(f"DoF y: {axis}")),
#         pyspacemouse.ButtonCallback([5, 2, 1], lambda axis: print(f"DoF y: {axis}")),
#         pyspacemouse.ButtonCallback([5, 4], lambda axis, s: print(f"DoF y: {axis}")),
#     ]
# )
#
# dev = pyspacemouse.device_specs["SpaceMouse Pro"]
# dev.check_config_sep(cfg)



# import pyspacemouse
# import time
#
#
# pyspacemouse.open(dof_callback_arr=[
#     pyspacemouse.DofCallback("x", lambda state, axis: print(f"X plus {axis}"), 0.01, lambda state, axis: print(f"X minus {axis}")),
#     pyspacemouse.DofCallback("y", lambda state, axis: print(f"Y plus {axis}"), 0.01, lambda state, axis: print(f"Y minus {axis}"), 0.5),
# ])
#
#
# while True:
#     out = pyspacemouse.read()
#     # print(out.x)
#     time.sleep(0.0001)




import pyspacemouse
import time

pyspacemouse.open(dof_callback_arr=[
    pyspacemouse.DofCallback("x", lambda state, axis: print(f"X filter {axis}"), 0.01, None, 0.3),
    pyspacemouse.DofCallback("y", lambda state, axis: print(f"Y filter {axis}"), 0.01, None, 0.8),
    # pyspacemouse.DofCallback("z", lambda state, axis: print(f"z filter {axis}"), 0.01),
])


while True:
    out = pyspacemouse.read()
    # print(out.x)
    time.sleep(0.0001)



import unittest
import re

def reg(input, input2):
    raise Exception("asd")

class raiseTest(unittest.TestCase):
    def testraiseRegex(self):
        self.assertRaisesRegexp(Exception, "a", reg, "Point", "TutorialsPoint")


if __name__ == '__main__':
    unittest.main()


import pyspacemouse
import time

def test(info):
    print(f"Test: {info}")


def call1(state, buttons):
    print("Success-1")


def call2(state, buttons):
    print("Success-2")


def success():
    test("Press button 0 or 1")
    arr_success = [
        pyspacemouse.ButtonCallback([0], call1),
        pyspacemouse.ButtonCallback([1], call2),
    ]
    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()


def err_arr_arr_string():
    test("Press button 0 or 1")
    arr_success = [
        pyspacemouse.ButtonCallback(["1", "1.1"], call1),
        pyspacemouse.ButtonCallback(["2"], call2),
    ]
    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()


def err_arr_num_string():
    test("Press button 0 or 1")
    arr_success = [
        pyspacemouse.ButtonCallback("1", call1),
        pyspacemouse.ButtonCallback("2", call2),
    ]
    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()


def err_obj_arr_string():
    test("Press button 0 or 1")
    arr_success = pyspacemouse.ButtonCallback(["1"], call1)

    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()


def err_obj_num_string():
    test("Press button 0 or 1")
    arr_success = pyspacemouse.ButtonCallback("1", call1)

    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()

def success_dof_callback():
    test("Move X axis")
    arr_success = [
        pyspacemouse.DofCallback("x", lambda axis: print("x:",axis)),
        pyspacemouse.DofCallback("pitch", lambda axis: print("pitch:", axis)),
        # pyspacemouse.ButtonCallback([1], call2),
    ]
    dev = pyspacemouse.open(dof_callback_arr=arr_success)
    while True:
        state = dev.read()
        time.sleep(0.0001)


if __name__ == '__main__':
    print("Start testing")
    # success()
    # err_arr_arr_string() #y
    # err_arr_num_string()
    # err_obj_arr_string() #y
    # err_obj_num_string()
    success_dof_callback()


import pyspacemouse
import time
import pyautogui

pyautogui.PAUSE = 0
pyautogui.MINIMUM_SLEEP = 0
pyautogui.MINIMUM_DURATION = 0

def test(info):
    print(f"Test: {info}")


def call1(state, buttons):
    print("Success-1")


def call2(state, buttons):
    print("Success-2")


def success():
    test("Press button 0 or 1")
    arr_success = [
        pyspacemouse.ButtonCallback([0], call1),
        pyspacemouse.ButtonCallback([1], call2),
    ]
    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()


def err_arr_arr_string():
    test("Press button 0 or 1")
    arr_success = [
        pyspacemouse.ButtonCallback(["1", "1.1"], call1),
        pyspacemouse.ButtonCallback(["2"], call2),
    ]
    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()


def err_arr_num_string():
    test("Press button 0 or 1")
    arr_success = [
        pyspacemouse.ButtonCallback("1", call1),
        pyspacemouse.ButtonCallback("2", call2),
    ]
    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()


def err_obj_arr_string():
    test("Press button 0 or 1")
    arr_success = pyspacemouse.ButtonCallback(["1"], call1)

    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()


def err_obj_num_string():
    test("Press button 0 or 1")
    arr_success = pyspacemouse.ButtonCallback("1", call1)

    dev = pyspacemouse.open(button_callback_arr=arr_success)
    while True:
        state = dev.read()

def success_dof_callback():
    test("Move X axis")
    arr_success = [
        pyspacemouse.DofCallback("x", lambda axis: print("x:",axis), 0.05),
        # pyspacemouse.DofCallback("pitch", lambda axis: pyautogui.scroll((axis*2)**3), 0.08),
        pyspacemouse.DofCallback("pitch", lambda axis: pyautogui.scroll((axis*5)), 0.09),
        # pyspacemouse.ButtonCallback([1], call2),
    ]
    dev = pyspacemouse.open(dof_callback_arr=arr_success)
    while True:
        state = dev.read()
        time.sleep(0.0001)


def success_dof_callback_cfg():
    test("Move X axis")
    arr_success = [
        pyspacemouse.DofCallback("x", lambda axis: print("x:",axis), 0.05),
        # pyspacemouse.DofCallback("pitch", lambda axis: pyautogui.scroll((axis*2)**3), 0.08),
        pyspacemouse.DofCallback("pitch", lambda axis: pyautogui.scroll((axis*5)), 0.09),
        # pyspacemouse.ButtonCallback([1], call2),
    ]

    cfg = pyspacemouse.Config(dof_callback_arr=arr_success)

    dev = pyspacemouse.openCfg(cfg)
    while True:
        state = dev.read()
        time.sleep(0.0001)


def success_dof_callback_set():
    test("Move X axis")
    arr_success = [
        pyspacemouse.DofCallback("x", lambda axis: print("x:",axis), 0.05),
        # pyspacemouse.DofCallback("pitch", lambda axis: pyautogui.scroll((axis*2)**3), 0.08),
        pyspacemouse.DofCallback("pitch", lambda axis: pyautogui.scroll((axis*5)), 0.09),
        # pyspacemouse.ButtonCallback([1], call2),
    ]

    cfg = pyspacemouse.Config(dof_callback_arr=arr_success)

    dev = pyspacemouse.open()
    dev.config_set(cfg)
    # dev.config_remove()
    while True:
        state = dev.read()
        time.sleep(0.0001)


def success_dof_callback_set_p():
    test("Move X axis")
    arr_success = [
        pyspacemouse.DofCallback("x", lambda state, axis: print("x:",axis), 0.05),
        # pyspacemouse.DofCallback("pitch", lambda state, axis: pyautogui.scroll((axis*2)**3), 0.08),
        pyspacemouse.DofCallback("pitch", lambda state, axis: pyautogui.scroll((axis*5)), 0.09),
        # pyspacemouse.ButtonCallback([1], call2),
    ]

    cfg = pyspacemouse.Config(dof_callback_arr=arr_success)

    pyspacemouse.open()
    pyspacemouse.config_set(cfg)
    # pyspacemouse.config_remove()
    while True:
        state = pyspacemouse.read()
        time.sleep(0.0001)

def mouse(state, axis):
    val = axis*4
    if axis > 0.0:
        # pyautogui.hotkey("up")
        for x in range(0, int(val)):
            pyautogui.press("up")
    elif axis < -0.0:
        for y in range(0, int(-val)):
            pyautogui.press("down")

def mouse_side(state, axis):
    val = axis*2
    print(val)
    if axis > 0.0:
        # pyautogui.hotkey("up")
        for x in range(1, int(val**3)):
            pyautogui.press("right")
    elif axis < -0.0:
        for y in range(1, int(-val**3)):
            pyautogui.press("left")

def success_dof_callback_set_mouse():
    test("Move X axis")
    arr_success = [
        # pyspacemouse.DofCallback("x", lambda state, axis: print("x:",axis), 0.05),
        # pyspacemouse.DofCallback("pitch", lambda state, axis: pyautogui.scroll((axis*2)**3), 0.08),
        pyspacemouse.DofCallback("pitch", mouse, 0.2),
        pyspacemouse.DofCallback("roll", mouse_side, 0.1),
        # pyspacemouse.DofCallback("yaw", mouse_side, 0.1),
        # pyspacemouse.ButtonCallback([1], call2),
    ]

    cfg = pyspacemouse.Config(dof_callback_arr=arr_success)

    pyspacemouse.open()
    pyspacemouse.config_set(cfg)
    # pyspacemouse.config_remove()
    while True:
        state = pyspacemouse.read()
        time.sleep(0.0001)

if __name__ == '__main__':
    print("Start testing")
    # success()
    # err_arr_arr_string() #y
    # err_arr_num_string()
    # err_obj_arr_string() #y
    # err_obj_num_string()
    # success_dof_callback()


    # success_dof_callback_set()
    # success_dof_callback_set_p()
    success_dof_callback_set_mouse()